# Configure paths for axel
# Conrad Parker 2001-09-18
# blatantly ripped from gtk.m4, Owen Taylor     97-11-3

dnl AM_PATH_AXEL([MINIMUM-VERSION, [ACTION-IF-FOUND [, ACTION-IF-NOT-FOUND]]])
dnl Test for axel, and define AXEL_CFLAGS and AXEL_LIBS.
dnl
AC_DEFUN(AM_PATH_AXEL,
[dnl 
dnl Get compiler flags and libraries from the axel-config script.
dnl
AC_ARG_WITH(axel-prefix,[  --with-axel-prefix=PFX   Prefix where axel is installed (optional)],
            axel_prefix="$withval", axel_prefix="")
AC_ARG_WITH(axel-exec-prefix,[  --with-axel-exec-prefix=PFX Exec prefix where axel is installed (optional)],
            axel_exec_prefix="$withval", axel_exec_prefix="")
AC_ARG_ENABLE(axeltest, [  --disable-axeltest       Do not try to compile and run a test axel program], , enable_axeltest=yes)

  if test x$axel_exec_prefix != x ; then
     axel_args="$axel_args --exec-prefix=$axel_exec_prefix"
     if test x${AXEL_CONFIG+set} != xset ; then
        AXEL_CONFIG=$axel_exec_prefix/bin/axel-config
     fi
  fi
  if test x$axel_prefix != x ; then
     axel_args="$axel_args --prefix=$axel_prefix"
     if test x${AXEL_CONFIG+set} != xset ; then
        AXEL_CONFIG=$axel_prefix/bin/axel-config
     fi
  fi

  AC_PATH_PROG(AXEL_CONFIG, axel-config, no)
  min_axel_version=ifelse([$1], ,0.2.0,$1)
  AC_MSG_CHECKING(for axel - version >= $min_axel_version)
  no_axel=""
  if test "$AXEL_CONFIG" = "no" ; then
    no_axel=yes
  else
    AXEL_LIBS=`$AXEL_CONFIG $axelconf_args --libs`
    AXEL_CFLAGS=`$AXEL_CONFIG $axelconf_args --cflags`
    axel_major_version=`$AXEL_CONFIG $axel_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
    axel_minor_version=`$AXEL_CONFIG $axel_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
    axel_micro_version=`$AXEL_CONFIG $axel_config_args --version | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`
    if test "x$enable_axeltest" = "xyes" ; then
      AC_LANG_SAVE
      AC_LANG_C
      ac_save_CFLAGS="$CFLAGS"
      ac_save_LIBS="$LIBS"
      CFLAGS="$CFLAGS $AXEL_CFLAGS"
      LIBS="$LIBS $AXEL_LIBS"
dnl
dnl Now check if the installed axel is sufficiently new. 
dnl (Also checks the sanity of the results of axel-config to some extent.)
dnl
      rm -f conf.axeltest
      AC_TRY_RUN([
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <axel.h>

char*
my_strdup (char *str)
{
  char *new_str;
  
  if (str)
    {
      new_str = malloc ((strlen (str) + 1) * sizeof(char));
      strcpy (new_str, str);
    }
  else
    new_str = NULL;
  
  return new_str;
}

int main ()
{
  int major, minor, micro;
  char *tmp_version;

  system ("touch conf.axeltest");

  /* HP/UX 9 (%@#!) writes to sscanf strings */
  tmp_version = my_strdup("$min_axel_version");
  if (sscanf(tmp_version, "%d.%d.%d", &major, &minor, &micro) != 3) {
     printf("%s, bad version string\n", "$min_axel_version");
     exit(1);
   }

   if (($axel_major_version > major) ||
      (($axel_major_version == major) && ($axel_minor_version > minor)) ||
      (($axel_major_version == major) && ($axel_minor_version == minor) && ($axel_micro_version >= micro)))
    {
      return 0;
    }
  else
    {
      printf("\n*** 'axel-config --version' returned %d.%d.%d, but the minimum version\n", $axel_major_version, $axel_minor_version, $axel_micro_version);
      printf("*** of axel required is %d.%d.%d. If axel-config is correct, then it is\n", major, minor, micro);
      printf("*** best to upgrade to the required version.\n");
      printf("*** If axel-config was wrong, set the environment variable AXEL_CONFIG\n");
      printf("*** to point to the correct copy of axel-config, and remove the file\n");
      printf("*** config.cache before re-running configure\n");
      return 1;
    }
}

],, no_axel=yes,[echo $ac_n "cross compiling; assumed OK... $ac_c"])
       CFLAGS="$ac_save_CFLAGS"
       LIBS="$ac_save_LIBS"
       AC_LANG_RESTORE
     fi
  fi
  if test "x$no_axel" = x ; then
     AC_MSG_RESULT(yes)
     ifelse([$2], , :, [$2])     
  else
     AC_MSG_RESULT(no)
     if test "$AXEL_CONFIG" = "no" ; then
       cat <<END
*** The axel-config script installed by the axel could
*** not be found.  If the axel was installed in PREFIX, make
*** sure PREFIX/bin is in your path, or set the AXEL_CONFIG
*** environment variable to the full path to axel-config.
END
     else
       if test -f conf.axeltest ; then
        :
       else
          echo "*** Could not run axel test program; checking why..."
          AC_LANG_SAVE
          AC_LANG_C
          CFLAGS="$CFLAGS $AXEL_CFLAGS"
          LIBS="$LIBS $AXEL_LIBS"
          AC_TRY_LINK([
#include <stdio.h>
#include <axel.h>
],      [ return 0; ],
        [ cat <<END
*** The test program compiled, but did not run.  This usually means that
*** the run-time linker is not finding axel or finding the wrong version
*** of axel.
***
*** If it is not finding axel, you'll need to set your LD_LIBRARY_PATH
*** environment variable, or edit /etc/ld.so.conf to point to the
*** installed location.  Also, make sure you have run ldconfig if that is
*** required on your system.
***
*** If you have an old version installed, it is best to remove it, although
*** you may also be able to get things to work by modifying
*** LD_LIBRARY_PATH.
END
        ],
        [ echo "*** The test program failed to compile or link. See the file config.log"
          echo "*** for the exact error that occured. This usually means axel"
          echo "*** was incorrectly installed or that you have moved axel"
          echo "*** since it was installed. In the latter case, you may want"
          echo "*** to edit the axel-config script: $AXEL_CONFIG" ])
          CFLAGS="$ac_save_CFLAGS"
          LIBS="$ac_save_LIBS"
          AC_LANG_RESTORE
       fi
     fi
     AXEL_CFLAGS=""
     AXEL_LIBS=""
     ifelse([$3], , :, [$3])
  fi
  AC_SUBST(AXEL_CFLAGS)
  AC_SUBST(AXEL_LIBS)
  rm -f conf.axeltest
])
