/*
 * AXEL -- An audio mixing and sequencing library.
 *
 * Copyright (C) 2001 Commonwealth Scientific and Industrial Research
 * Organisation (CSIRO), Australia.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * AxMetaText: Metadata for AxBases.
 *
 * Conrad Parker <Conrad.Parker@CSIRO.AU>, August 2001
 */


#define __AXEL__
#include "axel.h"

#include <string.h>

AxMetaText
ax_meta_text_new (AXEL axel)
{
  AxMetaText mt;

  mt = (AxMetaText) ax_malloc (sizeof (struct _AxMetaText));

  return mt;
}

char *
ax_meta_text_get_identifier (AXEL axel, AxMetaText mt)
{
  return mt->identifier;
}

char *
ax_meta_text_set_identifier (AXEL axel, AxMetaText mt, char * identifier)
{
  char * old = mt->identifier;
  mt->identifier = (identifier == NULL) ? NULL : strdup(identifier);
  return old;
}

char *
ax_meta_text_get_category (AXEL axel, AxMetaText mt)
{
  return mt->category;
}

char *
ax_meta_text_set_category (AXEL axel, AxMetaText mt, char * category)
{
  char * old = mt->category;
  mt->category = (category == NULL) ? NULL : strdup(category);
  return old;
}

char *
ax_meta_text_get_description (AXEL axel, AxMetaText mt)
{
  return mt->description;
}

char *
ax_meta_text_set_description (AXEL axel, AxMetaText mt, char * description)
{
  char * old = mt->description;
  mt->description = (description == NULL) ? NULL : strdup(description);
  return old;
}

char *
ax_meta_text_get_copyright (AXEL axel, AxMetaText mt)
{
  return mt->copyright;
}

char *
ax_meta_text_set_copyright (AXEL axel, AxMetaText mt, char * copyright)
{
  char * old = mt->copyright;
  mt->copyright = (copyright == NULL) ? NULL : strdup(copyright);
  return old;
}

char *
ax_meta_text_get_url (AXEL axel, AxMetaText mt)
{
  return mt->url;
}

char *
ax_meta_text_set_url (AXEL axel, AxMetaText mt, char * url)
{
  char * old = mt->url;
  mt->url = (url == NULL) ? NULL : strdup(url);
  return old;
}

static AxMetaAuthor
ax_meta_author_new (AXEL axel, char * name, char * email)
{
  AxMetaAuthor ma = ax_malloc (sizeof (struct _AxMetaAuthor));
  ma->name = (name == NULL) ? NULL : strdup(name);
  ma->email = (email == NULL) ? NULL: strdup(email);
  return ma;
}

CDList
ax_meta_text_get_authors (AXEL axel, AxMetaText mt)
{
  return mt->authors;
}
 
void
ax_meta_text_add_author (AXEL axel, AxMetaText mt, char * name, char * email)
{
  AxMetaAuthor ma = ax_meta_author_new (axel, name, email);
  mt->authors = cd_list_append (axel, mt->authors, CD_POINTER(ma));
}

void
ax_meta_text_free (AXEL axel, AxMetaText mt)
{
  cd_list_free_all (axel, mt->authors);
  ax_free (mt);
}
