/*
 * syssimple
 *
 * Copyright (C) 2001 Commonwealth Scientific and Industrial Research
 * Organisation (CSIRO), Australia.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * ss_error -- basic error handling.
 *
 * Conrad Parker <Conrad.Parker@CSIRO.AU>, August 2001
 */

#include <string.h>
#include <errno.h>
#include <stdarg.h>

#include "syssimple.h"

/*
 * ss_exit_err (fmt)
 *
 * Print a formatted error message and errno information to stderr,
 * then exit with return code 1.
 */
void
ss_exit_err (const char * fmt, ...)
{
  va_list ap;
  int errno_save;
  char buf[SS_MAXLINE];
  int n;

  errno_save = errno;

  va_start (ap, fmt);

  vsnprintf (buf, SS_MAXLINE, fmt, ap);
  n = strlen (buf);

  snprintf (buf+n, SS_MAXLINE-n, ": %s\n", strerror (errno_save));

  fflush (stdout); /* in case stdout and stderr are the same */
  fputs (buf, stderr);
  fflush (NULL);

  va_end (ap);
  exit (1);
}

/*
 * ss_print_err (fmt)
 *
 * Print a formatted error message to stderr.
 */
void
ss_print_err (const char * fmt, ...)
{
  va_list ap;
  int errno_save;
  char buf[SS_MAXLINE];

  errno_save = errno;

  va_start (ap, fmt);

  vsnprintf (buf, SS_MAXLINE, fmt, ap);

  fflush (stdout); /* in case stdout and stderr are the same */
  fputs (buf, stderr);
  fputc ('\n', stderr);
  fflush (NULL);

  va_end (ap);
}

/*
 * ss_print_debug (level, fmt)
 *
 * Print a formatted debugging message of level 'level' to stderr
 */

