/*
 * syssimple
 *
 * Copyright (C) 2001 Commonwealth Scientific and Industrial Research
 * Organisation (CSIRO), Australia.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

/*
 * Conrad Parker <Conrad.Parker@CSIRO.AU>, August 2001
 */

#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <pwd.h>
#include <sys/types.h>

#include "syssimple.h"

/*
 * ss_malloc (size)
 *
 * Malloc wrapper. Always returns a successful allocation. Exits if the
 * allocation didn't succeed.
 */
void *
ss_malloc (size_t size)
{
  void * ret;

  if ((ret = calloc (1, size)) == NULL) {
    ss_exit_err ("alloc error");
  }

  return ret;
}

/*
 * ax_free (ptr)
 *
 * Free wrapper. Free from the same pool allocator as ax_malloc().
 */
void
ss_free (void * ptr)
{
  free (ptr);
}

/*
 * ax_get_homedir ()
 *
 * Get the user's home directory.
 */
char *
ss_get_homedir (void)
{
  uid_t uid;
  char * username, * homedir;
  struct passwd * pw;

  if ((homedir = getenv ("HOME")) != NULL) {
    return homedir;
  }

  /* else ... go hunting for it */
  uid = getuid ();

  username = getenv ("LOGNAME");
  if (!username) username = getenv ("USER");

  if (username) {
    pw = getpwnam (username);
    if (pw && pw->pw_uid == uid) goto gotpw;
  }

  pw = getpwuid (uid);

gotpw:

  if (!pw) {
    ss_exit_err ("error retrieving passwd entry");
  }

  homedir = strdup (pw->pw_dir);

  return homedir;
}

