/*
 * sndfiletest.c
 *
 * Copyright (C) 2001 Commonwealth Scientific and Industrial Research
 * Organisation (CSIRO), Australia.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.  No representations are made about the suitability of this
 * software for any purpose.  It is provided "as is" without express or
 * implied warranty.
 *
 */

#include <axel.h>

int
main (int argc, char ** argv)
{
  AXEL axel;
  AxDeck deck, deck2;
  AxTrack track, track2, track3;
  AxLayer l1, l2, l3, l4, l5;
  AxBase sf1, sf2;
  AxSquareTone square;
  AxCount length;
  AxMonitor monitor;
  AxSound sm;
  AxEnvelope env;
  AxPlugin gain_plugin;
  AxPlugin sf_plugin;
  AxBase gain;
  CDSet sf_parms;
  int i;
  int gain_key;
  int sf_path_key;

  axel = axel_init ();
  ax_set_tempo (axel, 140);
  ax_set_channels (axel, AX_STEREO);

#if 0
  sf1 = ax_sndfile_new (axel, "./1052.wav", 0);
  sf2 = ax_sndfile_new (axel, "./909_cl.wav", 0);
#else
  sf_plugin = ax_find_plugin (axel, "builtin::sndfile_reader");
  sf_parms = cd_set_new (axel);
  sf_path_key = ax_get_init_parameter_key (axel, sf_plugin, "path");
  sf_parms = cd_set_insert (axel, sf_parms, sf_path_key,
		            CD_STRING("./1052.wav"));
  if (sf_plugin == NULL) {
    fprintf (stderr, "sf_plugin == NULL\n");
    exit (1);
  }
  sf1 = ax_new (axel, sf_plugin, sf_parms);
  sf_parms = cd_set_replace (axel, sf_parms, 1, CD_STRING("909_cl.wav"));
  sf2 = ax_new (axel, sf_plugin, sf_parms);
#endif
  square = ax_squaretone_new (axel, 220);
  monitor = ax_monitor_new (axel);

#if 0
  gain = ax_gain_new (axel);
#else
  gain_plugin = ax_find_plugin (axel, "builtin::gain");
  gain = ax_new (axel, gain_plugin, NULL);
#endif

  env = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, env, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, env, AX_BEAT24S(0), 0.1);
  ax_envelope_add_point (axel, env, AX_BEAT24S(48), 1.3);
  ax_envelope_add_point (axel, env, AX_BEAT24S(96), 0.1);

#if 0
  ax_gain_set_envelope (axel, gain, env);
#else
  gain_key = ax_get_parameter_key (axel, gain, "Gain envelope");
  printf ("got gain key: %d\n", gain_key);
  ax_set_parameter (axel, gain, gain_key, (CDScalar)((void *)env));
#endif

  deck = ax_deck_new (axel);
  track = ax_add_track (axel, deck);

  l1 = ax_add_layer_ontop (axel, track, AX_TIME_BEAT24S);
  for (i=0; i < 4; i++) {
    ax_add_sound (axel, (AxBase)sf1, l1, AX_BEAT24S(i*24), AX_BEAT24S(18));
  }

  track2 = ax_add_track (axel, deck);
  l2 = ax_add_layer_ontop (axel, track2, AX_TIME_BEAT24S);
  for (i=0; i < 16; i++) {
    ax_add_sound (axel, (AxBase)sf2, l2, AX_BEAT24S(i*6), AX_BEAT24S(4));
  }

  deck2 = ax_deck_new (axel);
  track3 = ax_add_track (axel, deck2);

  l3 = ax_add_layer_ontop (axel, track3, AX_TIME_BEAT24S);
  ax_add_sound (axel, (AxBase)deck, l3, AX_BEAT24S(0), AX_BEAT24S(96));

#if 1
  l4 = ax_add_layer_ontop (axel, track3, AX_TIME_BEAT24S);
  ax_add_sound (axel, (AxBase)gain, l4, AX_BEAT24S(0), AX_BEAT24S(96));
#endif

  l5 = ax_add_layer_ontop (axel, track3, AX_TIME_SAMPLES);

  length = ax_length (axel, (AxBase)deck);
  sm = ax_add_sound (axel, monitor, l5, AX_SAMPLES(0), AX_SAMPLES(length));

  printf ("deck: %p\ttrack: %p\tl1: %p\nl3: %p\tmonitor: %p\n",
          deck, track, l1, l3, monitor);

  ax_process (axel, deck2, length, AxNone, AxNone);

  ax_set_tempo (axel, 105);
  length = ax_length (axel, (AxBase)deck);
  ax_sound_set_duration (axel, sm, AX_SAMPLES(length));
  ax_seek (axel, deck2, 0);
  ax_process (axel, deck2, length, AxNone, AxNone);

  ax_set_tempo (axel, 168);
  length = ax_length (axel, (AxBase)deck);
  ax_sound_set_duration (axel, sm, AX_SAMPLES(length));
  ax_seek (axel, deck2, 0);
  ax_process (axel, deck2, length, AxNone, AxNone);

  axel_purge (axel);

  exit (0);
}
