/*
 * squaretest.c
 *
 * Copyright (C) 2001 Commonwealth Scientific and Industrial Research
 * Organisation (CSIRO), Australia.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation.  No representations are made about the suitability of this
 * software for any purpose.  It is provided "as is" without express or
 * implied warranty.
 *
 */

#include <axel.h>

#define ax_add_sound_B(a,s,l,t1,t2) \
  ax_add_sound ((a), (s), (l), AX_BEAT24S(t1), AX_BEAT24S(t2))

#define BEAT 24
#define HALF_BEAT 12
#define QUARTER_BEAT 6
#define EIGHTH_BEAT 3

int
main (int argc, char ** argv)
{
  AXEL axel;
  AxDeck deck, deck2;
  AxTrack track, track2, track3, track4;
  AxLayer l1, l2, l3, l4, l5;
  AxSound s;
  AxSquareTone square1, square2, square3, square4, square5;
  AxPlugin noise_plugin;
  AxBase noise;
  AxEnvelope env1, env2, env3;
  AxEnvelope be1, be2, be3;
  AxCount length;
  AxMonitor monitor;
  int b = 0, b2 = 0, mb;

  axel = axel_init ();

  ax_set_tempo (axel, 160);
  ax_set_channels (axel, AX_STEREO);

  square1 = ax_squaretone_new (axel, 220.0);
  square2 = ax_squaretone_new (axel, 440.0);
  square3 = ax_squaretone_new (axel, 385.0);
  square4 = ax_squaretone_new (axel, 231.0);
  square5 = ax_squaretone_new (axel, 165.0);

  noise_plugin = ax_find_plugin (axel, "builtin::noise");
  noise = ax_new (axel, noise_plugin, NULL);

  monitor = ax_monitor_new (axel);

  deck = ax_deck_new (axel);

#if 1
  track = ax_add_track (axel, deck);

  l1 = ax_add_layer_ontop (axel, track, AX_TIME_BEAT24S);
  ax_add_sound_B (axel, square1, l1, b, BEAT); b += BEAT;
#if 1
  ax_add_sound_B (axel, square2, l1, b, QUARTER_BEAT); b += HALF_BEAT;
  ax_add_sound_B (axel, square2, l1, b, HALF_BEAT); b += HALF_BEAT;
  ax_add_sound_B (axel, square1, l1, b, HALF_BEAT); b += HALF_BEAT;
  ax_add_sound_B (axel, square2, l1, b, QUARTER_BEAT); b += HALF_BEAT;
  ax_add_sound_B (axel, square3, l1, b, HALF_BEAT); b += HALF_BEAT;
  ax_add_sound_B (axel, square2, l1, b, HALF_BEAT); b += HALF_BEAT;
#endif
#endif

#if 1
#if 1
  track2 = ax_add_track (axel, deck);
  ax_track_set_gain (axel, track2, 0.6);
#else
  track2 = track;
#endif
  l2 = ax_add_layer_ontop (axel, track2, AX_TIME_BEAT24S);
  s = ax_add_sound_B (axel, square4, l2, b2, HALF_BEAT); b2 += BEAT;

  be1 = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, be1, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, be1, AX_BEAT24S(0), 0.9);
  ax_sound_set_blend_envelope (axel, s, be1);

#if 1
  s = ax_add_sound_B (axel, square5, l2, b2, HALF_BEAT); b2 += BEAT;
  be2 = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, be2, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, be2, AX_BEAT24S(0), 0.6);
  ax_sound_set_blend_envelope (axel, s, be2);

  s = ax_add_sound_B (axel, square4, l2, b2, BEAT); b2 += 48;
  be3 = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, be3, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, be3, AX_BEAT24S(0), 0.8);
  ax_sound_set_blend_envelope (axel, s, be3);
#endif
#endif

#if 1
  track4 = ax_add_track (axel, deck);
  ax_track_set_gain (axel, track4, 0.1);
  l5 = ax_add_layer_ontop (axel, track4, AX_TIME_BEAT24S);
  ax_add_sound_B (axel, noise, l5, 0, b);
#endif

  mb = MAX (b, b2);

  length = ax_length (axel, deck);
  printf ("deck has length %ld\n", length);

  deck2 = ax_deck_new (axel);
  track3 = ax_add_track (axel, deck2);
  l3 = ax_add_layer_ontop (axel, track3, AX_TIME_BEAT24S);

  s = ax_add_sound_B (axel, deck, l3, 0, mb);

#if 1
  env1 = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, env1, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, env1, AX_BEAT24S(0), 0.0);
  ax_envelope_add_point (axel, env1, AX_BEAT24S(mb), 0.9);
  ax_sound_set_gain_envelope (axel, s, env1);
#endif

  s = ax_add_sound_B (axel, deck, l3, mb, mb);

#if 1
  env2 = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, env2, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, env2, AX_BEAT24S(0), 0.9);
  ax_sound_set_gain_envelope (axel, s, env2);
#endif

  s = ax_add_sound_B (axel, deck, l3, 2*mb, mb);

#if 1
  env3 = ax_envelope_new (axel, AX_ENVELOPE_LINEAR);
  ax_envelope_set_timetype (axel, env3, AX_TIME_BEAT24S);
  ax_envelope_add_point (axel, env3, AX_BEAT24S(0), 0.9);
  ax_envelope_add_point (axel, env3, AX_BEAT24S(mb), 0.0);
  ax_sound_set_gain_envelope (axel, s, env3);
#endif

  length = ax_length (axel, deck2);

  l4 = ax_add_layer_ontop (axel, track3, AX_TIME_SAMPLES);
  ax_add_sound (axel, monitor, l4, AX_SAMPLES(0), AX_SAMPLES(length));

  printf ("deck: %p\ttrack: %p\tl1: %p\ttrack2: %p\tl2: %p\n",
          deck, track, l1, track2, l2);
  printf ("deck2: %p\ttrack3: %p\tl3: %p\tl4: %p\n", deck2, track3, l3, l4);
  printf ("square1: %p\tsquare2: %p\tsquare3: %p\nsquare4: %p\tsquare5: %p\n",
          square1, square2, square3, square4, square5);
  printf ("monitor: %p\n", monitor);

  ax_process (axel, deck2, length, AxNone, AxNone);

  axel_purge (axel);

  exit (0);
}
